Miscellaneous
-------------

.. currentmodule:: prismstudio

.. autosummary::
    :toctree: api/

    _PrismComponent.resample
    _PrismComponent.fillna
    _PrismComponent.map
    _PrismComponent.isin